@@ -54,7 +54,7 @@ each gene. The read copy number is not used in this analysis.
 =cut
 
 package CLIPSeqTools::App::distribution_on_genic_elements;
-$CLIPSeqTools::App::distribution_on_genic_elements::VERSION = '0.1.2';
+$CLIPSeqTools::App::distribution_on_genic_elements::VERSION = '0.1.3';
 
 # Make it an app command
 use MooseX::App::Command;
@@ -240,7 +240,7 @@ sub count_copy_number_in_bins_of_element {
 			my $pos = $elm->relative_exonic_position($read->mid_position);
 			return 0 if !defined $pos;
 
-			$pos =	$elm_exon_length - $pos if $elm->strand == -1;
+			$pos =	$elm_exon_length - $pos - 1 if $elm->strand == -1;
 
 			my $bin = int($bins * ($pos / $elm_exon_length));
 			$counts[$bin] += 1; #$read->copy_number;
